@@ -37,13 +37,12 @@ func TestYamlFormatter_RenderChecks(t *testing.T) {
 			Id:          "change_id",
 			Level:       "info",
 			Description: "This is a breaking change.",
-			Required:    true,
 		},
 	}
 
 	out, err := yamlFormatter.RenderChecks(checks, formatters.NewRenderOpts())
 	require.NoError(t, err)
-	require.Equal(t, "- id: change_id\n  level: info\n  description: This is a breaking change.\n  required: true\n", string(out))
+	require.Equal(t, "- id: change_id\n  level: info\n  description: This is a breaking change.\n", string(out))
 }
 
 func TestYamlFormatter_RenderDiff(t *testing.T) {
